#region File Description
//-----------------------------------------------------------------------------
// SpinningSphereControl.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//-----------------------------------------------------------------------------
#endregion

#region Using Statements
using System;
using System.Diagnostics;
using System.Windows.Forms;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
#endregion

namespace FilmDBExtractor
{
    /// <summary>
    /// Example control inherits from GraphicsDeviceControl, which allows it to
    /// render using a GraphicsDevice. This control shows how to draw animating
    /// 3D graphics inside a WinForms application. It hooks the Application.Idle
    /// event, using this to invalidate the control, which will cause the animation
    /// to constantly redraw.
    /// </summary>
    class SpinningSphereControl : GraphicsDeviceControl
    {
        // Variables for the Sphere
        VertexDeclaration vertexDeclaration;
        BasicEffect effect;
        Stopwatch timer;
        int totalpoints = 0;
        VertexPositionColor[] vertices; // Vertex positions and colors used to display a spinning Sphere.


        // Variables for the Text
        ContentManager content;
        SpriteBatch spriteBatch;
        SpriteFont font;


        /// <summary>
        /// Initializes the control, creating the ContentManager
        /// and using it to load a SpriteFont.
        /// </summary>
        protected override void Initialize()
        {
            // Create the ContentManager to load the Font
            content = new ContentManager(Services, "Content");
            font = content.Load<SpriteFont>("Arial");

            // Initialize the SpriteBatch to Display our Text
            spriteBatch = new SpriteBatch(GraphicsDevice);

            SetUpVertices();
            // Create our vertex declaration.
            vertexDeclaration = new VertexDeclaration(GraphicsDevice, VertexPositionColor.VertexElements);

            // Create our effect.
            effect = new BasicEffect(GraphicsDevice, null);

            effect.VertexColorEnabled = true;

            // Start the animation timer.
            timer = Stopwatch.StartNew();

            // Hook the idle event to constantly redraw our animation.
            Application.Idle += delegate { Invalidate(); };
        }

        /// <summary>
        /// Disposes the control, unloading the ContentManager.
        /// </summary>
        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                content.Unload();
            }
            base.Dispose(disposing);
        }

        private void SetUpVertices()
        {
            vertices = new VertexPositionColor[2369];
            double x, y, z, tempx = 0;
            float r, h, x1, y1, z1, theta;
            float radius = 5.05f;
            for (h = radius + 1; h >= -radius; h -= 0.225f)
            {
                tempx = (double)((radius * radius) - (h * h));
                r = (float)Math.Sqrt(tempx);
                for (theta = 0.0f; theta <= 360; theta += 18)
                {
                    x = r * Math.Sin(theta * MathHelper.Pi / 180);
                    y = h;
                    z = r * Math.Cos(theta * MathHelper.Pi / 180);
                    x1 = (float)x;
                    y1 = (float)y;
                    z1 = (float)z;
                    vertices[totalpoints].Position = new Vector3(x1, y1, z1);
                    vertices[totalpoints].Color = Color.White;
                    ++totalpoints;
                }
            }
        }

        /// <summary>
        /// Draws the control.
        /// </summary>
        protected override void Draw()
        {
            GraphicsDevice.Clear(Color.Black);
            const string ProductName = "~FilmDBExtractor~";
            const string ProductVersion = "Version: 0.0.1";
            const string ProductAuthor = "Created by regalis";
            
            // Spin the triangle according to how much time has passed.
            float time = (float)timer.Elapsed.TotalSeconds;

            float yaw = time * 0.7f;
            float pitch = time * 0.8f;
            float roll = time * 0.9f;

            // Set transform matrices.
            float aspect = GraphicsDevice.Viewport.AspectRatio;
            effect.World = Matrix.CreateFromYawPitchRoll(yaw, pitch, roll);

            // Setup the Camera
            effect.View = Matrix.CreateLookAt(new Vector3(0, 0, 20), Vector3.Zero, Vector3.Up);
            effect.Projection = Matrix.CreatePerspectiveFieldOfView(1, aspect, 1, 300);

            // Set renderstates.
            GraphicsDevice.RenderState.CullMode = CullMode.None;
            GraphicsDevice.VertexDeclaration = vertexDeclaration;

            // Draw the triangle.
            effect.Begin();
            effect.CurrentTechnique.Passes[0].Begin();
            GraphicsDevice.DrawUserPrimitives(PrimitiveType.PointList, vertices, 0, totalpoints);
            effect.CurrentTechnique.Passes[0].End();
            effect.End();

            // Draw the Text
            spriteBatch.Begin();
            spriteBatch.DrawString(font, ProductName, new Vector2(50, 20), Color.White);
            spriteBatch.DrawString(font, ProductVersion, new Vector2(350, 20), Color.White);
            spriteBatch.DrawString(font, ProductAuthor, new Vector2(150, 450), Color.White);
            spriteBatch.End();
        }
    }
}



#region Original
/*
#region File Description
//-----------------------------------------------------------------------------
// SpinningTriangleControl.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//-----------------------------------------------------------------------------
#endregion

#region Using Statements
using System.Diagnostics;
using System.Windows.Forms;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
#endregion

namespace FilmDBExtractor
{
    /// <summary>
    /// Example control inherits from GraphicsDeviceControl, which allows it to
    /// render using a GraphicsDevice. This control shows how to draw animating
    /// 3D graphics inside a WinForms application. It hooks the Application.Idle
    /// event, using this to invalidate the control, which will cause the animation
    /// to constantly redraw.
    /// </summary>
    class SpinningTriangleControl : GraphicsDeviceControl
    {
        VertexDeclaration vertexDeclaration;
        BasicEffect effect;
        Stopwatch timer;


        // Vertex positions and colors used to display a spinning triangle.
        public readonly VertexPositionColor[] Vertices =
        {
            new VertexPositionColor(new Vector3(-1, -1, 0), Color.Black),
            new VertexPositionColor(new Vector3( 1, -1, 0), Color.Black),
            new VertexPositionColor(new Vector3( 0,  1, 0), Color.Black),
        };


        /// <summary>
        /// Initializes the control.
        /// </summary>
        protected override void Initialize()
        {
            // Create our vertex declaration.
            vertexDeclaration = new VertexDeclaration(GraphicsDevice,
                                                VertexPositionColor.VertexElements);

            // Create our effect.
            effect = new BasicEffect(GraphicsDevice, null);

            effect.VertexColorEnabled = true;

            // Start the animation timer.
            timer = Stopwatch.StartNew();

            // Hook the idle event to constantly redraw our animation.
            Application.Idle += delegate { Invalidate(); };
        }


        /// <summary>
        /// Draws the control.
        /// </summary>
        protected override void Draw()
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);

            // Spin the triangle according to how much time has passed.
            float time = (float)timer.Elapsed.TotalSeconds;

            float yaw = time * 0.7f;
            float pitch = time * 0.8f;
            float roll = time * 0.9f;

            // Set transform matrices.
            float aspect = GraphicsDevice.Viewport.AspectRatio;

            effect.World = Matrix.CreateFromYawPitchRoll(yaw, pitch, roll);

            effect.View = Matrix.CreateLookAt(new Vector3(0, 0, -5),
                                              Vector3.Zero, Vector3.Up);

            effect.Projection = Matrix.CreatePerspectiveFieldOfView(1, aspect, 1, 10);

            // Set renderstates.
            GraphicsDevice.RenderState.CullMode = CullMode.None;

            GraphicsDevice.VertexDeclaration = vertexDeclaration;

            // Draw the triangle.
            effect.Begin();
            effect.CurrentTechnique.Passes[0].Begin();

            GraphicsDevice.DrawUserPrimitives(PrimitiveType.TriangleList,
                                              Vertices, 0, 1);

            effect.CurrentTechnique.Passes[0].End();
            effect.End();
        }
    }
}
*/
#endregion